@@ -129,8 +129,8 @@ CervisiaPart::CervisiaPart( TQWidget *parentWidget, const char *widgetName,
     // an explaination
     if( cvsService )
     {
-        Qt::Orientation o = splitHorz ? Qt::Vertical
-                                  : Qt::Horizontal;
+        TQt::Orientation o = splitHorz ? TQt::Vertical
+                                  : TQt::Horizontal;
         splitter = new TQSplitter(o, parentWidget, widgetName);
         // avoid PartManager's warning that Part's window can't handle focus
         splitter->setFocusPolicy( TQWidget::StrongFocus );
@@ -138,10 +138,10 @@ CervisiaPart::CervisiaPart( TQWidget *parentWidget, const char *widgetName,
         update = new UpdateView(*config(), splitter);
         update->setFocusPolicy( TQWidget::StrongFocus );
         update->setFocus();
-        connect( update, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
-                 this, TQT_SLOT(popupRequested(TDEListView*, TQListViewItem*, const TQPoint&)) );
-        connect( update, TQT_SIGNAL(fileOpened(TQString)),
-                 this, TQT_SLOT(openFile(TQString)) );
+        connect( update, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+                 this, TQ_SLOT(popupRequested(TDEListView*, TQListViewItem*, const TQPoint&)) );
+        connect( update, TQ_SIGNAL(fileOpened(TQString)),
+                 this, TQ_SLOT(openFile(TQString)) );
 
         protocol = new ProtocolView(appId, splitter);
         protocol->setFocusPolicy( TQWidget::StrongFocus );
@@ -157,12 +157,12 @@ CervisiaPart::CervisiaPart( TQWidget *parentWidget, const char *widgetName,
     {
         setupActions();
         readSettings();
-        connect( update, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( updateActions() ) );
+        connect( update, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( updateActions() ) );
     }
 
     setXMLFile( "cervisiaui.rc" );
 
-    TQTimer::singleShot(0, this, TQT_SLOT(slotSetupStatusBar()));
+    TQTimer::singleShot(0, this, TQ_SLOT(slotSetupStatusBar()));
 }
 
 CervisiaPart::~CervisiaPart()
@@ -233,81 +233,81 @@ void CervisiaPart::setupActions()
     // File Menu
     //
     action = new TDEAction( i18n("O&pen Sandbox..."), "document-open", CTRL+Key_O,
-                          this, TQT_SLOT( slotOpenSandbox() ),
+                          this, TQ_SLOT( slotOpenSandbox() ),
                           actionCollection(), "file_open" );
     hint = i18n("Opens a CVS working folder in the main window");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     recent = new TDERecentFilesAction( i18n("Recent Sandboxes"), 0,
-                                     this, TQT_SLOT( openURL( const KURL & ) ),
+                                     this, TQ_SLOT( openURL( const KURL & ) ),
                                      actionCollection(), "file_open_recent" );
 
     action = new TDEAction( i18n("&Insert ChangeLog Entry..."), 0,
-                          this, TQT_SLOT( slotChangeLog() ),
+                          this, TQ_SLOT( slotChangeLog() ),
                           actionCollection(), "insert_changelog_entry" );
     hint = i18n("Inserts a new intro into the file ChangeLog in the toplevel folder");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Update"), "vcs_update", CTRL+Key_U,
-                          this, TQT_SLOT( slotUpdate() ),
+                          this, TQ_SLOT( slotUpdate() ),
                           actionCollection(), "file_update" );
     hint = i18n("Updates (cvs update) the selected files and folders");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Status"), "vcs_status", Key_F5,
-                          this, TQT_SLOT( slotStatus() ),
+                          this, TQ_SLOT( slotStatus() ),
                           actionCollection(), "file_status" );
     hint = i18n("Updates the status (cvs -n update) of the selected files and folders");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Edit"), 0,
-                          this, TQT_SLOT( slotOpen() ),
+                          this, TQ_SLOT( slotOpen() ),
                           actionCollection(), "file_edit" );
     hint = i18n("Opens the marked file for editing");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Reso&lve..."), 0,
-                          this, TQT_SLOT( slotResolve() ),
+                          this, TQ_SLOT( slotResolve() ),
                           actionCollection(), "file_resolve" );
     hint = i18n("Opens the resolve dialog with the selected file");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Commit..."), "vcs_commit", Key_NumberSign,
-                          this, TQT_SLOT( slotCommit() ),
+                          this, TQ_SLOT( slotCommit() ),
                           actionCollection(), "file_commit" );
     hint = i18n("Commits the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Add to Repository..."), "vcs_add", Key_Insert,
-                          this, TQT_SLOT( slotAdd() ),
+                          this, TQ_SLOT( slotAdd() ),
                           actionCollection(), "file_add" );
     hint = i18n("Adds (cvs add) the selected files to the repository");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Add &Binary..."), 0,
-                          this, TQT_SLOT( slotAddBinary() ),
+                          this, TQ_SLOT( slotAddBinary() ),
                           actionCollection(), "file_add_binary" );
     hint = i18n("Adds (cvs -kb add) the selected files as binaries to the repository");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Remove From Repository..."), "vcs_remove", Key_Delete,
-                          this, TQT_SLOT( slotRemove() ),
+                          this, TQ_SLOT( slotRemove() ),
                           actionCollection(), "file_remove" );
     hint = i18n("Removes (cvs remove) the selected files from the repository");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Rever&t"), 0,
-                          this, TQT_SLOT( slotRevert() ),
+                          this, TQ_SLOT( slotRevert() ),
                           actionCollection(), "file_revert_local_changes" );
     hint = i18n("Reverts (cvs update -C) the selected files (only cvs 1.11)");
     action->setToolTip( hint );
@@ -315,14 +315,14 @@ void CervisiaPart::setupActions()
 
     // context menu only
     action = new TDEAction( i18n("&Properties"), 0,
-                          this, TQT_SLOT( slotFileProperties() ),
+                          this, TQ_SLOT( slotFileProperties() ),
                           actionCollection(), "file_properties" );
 
     //
     // View Menu
     //
     action = new TDEAction( i18n("Stop"), "process-stop", Key_Escape,
-                          TQT_TQOBJECT(protocol), TQT_SLOT(cancelJob()),
+                          protocol, TQ_SLOT(cancelJob()),
                           actionCollection(), "stop_job" );
     action->setEnabled( false );
     hint = i18n("Stops any running sub-processes");
@@ -331,7 +331,7 @@ void CervisiaPart::setupActions()
 
 
     action = new TDEAction( i18n("Browse &Log..."), CTRL+Key_L,
-                          this, TQT_SLOT(slotBrowseLog()),
+                          this, TQ_SLOT(slotBrowseLog()),
                           actionCollection(), "view_log" );
     hint = i18n("Shows the revision tree of the selected file");
     action->setToolTip( hint );
@@ -339,46 +339,46 @@ void CervisiaPart::setupActions()
 
 #if 0
     action = new TDEAction( i18n("Browse Multi-File Log..."), 0,
-                          this, TQT_SLOT(slotBrowseMultiLog()),
+                          this, TQ_SLOT(slotBrowseMultiLog()),
                           actionCollection() );
 #endif
     action = new TDEAction( i18n("&Annotate..."), CTRL+Key_A,
-                          this, TQT_SLOT(slotAnnotate()),
+                          this, TQ_SLOT(slotAnnotate()),
                           actionCollection(), "view_annotate" );
     hint = i18n("Shows a blame-annotated view of the selected file");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Difference to Repository (BASE)..."), "vcs_diff", CTRL+Key_D,
-                          this, TQT_SLOT(slotDiffBase()),
+                          this, TQ_SLOT(slotDiffBase()),
                           actionCollection(), "view_diff_base" );
     hint = i18n("Shows the differences of the selected file to the checked out version (tag BASE)");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Difference to Repository (HEAD)..."), "vcs_diff", CTRL+Key_H,
-                          this, TQT_SLOT(slotDiffHead()),
+                          this, TQ_SLOT(slotDiffHead()),
                           actionCollection(), "view_diff_head" );
     hint = i18n("Shows the differences of the selected file to the newest version in the repository (tag HEAD)");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Last &Change..."), 0,
-                          this, TQT_SLOT(slotLastChange()),
+                          this, TQ_SLOT(slotLastChange()),
                           actionCollection(), "view_last_change" );
     hint = i18n("Shows the differences between the last two revisions of the selected file");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&History..."), 0,
-                          this, TQT_SLOT(slotHistory()),
+                          this, TQ_SLOT(slotHistory()),
                           actionCollection(), "view_history" );
     hint = i18n("Shows the CVS history as reported by the server");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Unfold File Tree"), 0,
-                          this , TQT_SLOT(slotUnfoldTree()),
+                          this , TQ_SLOT(slotUnfoldTree()),
                           actionCollection(), "view_unfold_tree" );
 
     hint = i18n("Opens all branches of the file tree");
@@ -386,7 +386,7 @@ void CervisiaPart::setupActions()
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Fold File Tree"), 0,
-                          this, TQT_SLOT(slotFoldTree()),
+                          this, TQ_SLOT(slotFoldTree()),
                           actionCollection(), "view_fold_tree" );
     hint = i18n("Closes all branches of the file tree");
     action->setToolTip( hint );
@@ -396,98 +396,98 @@ void CervisiaPart::setupActions()
     // Advanced Menu
     //
     action = new TDEAction( i18n("&Tag/Branch..."), 0,
-                          this, TQT_SLOT(slotCreateTag()),
+                          this, TQ_SLOT(slotCreateTag()),
                           actionCollection(), "create_tag" );
     hint = i18n("Creates a tag or branch for the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Delete Tag..."), 0,
-                          this, TQT_SLOT(slotDeleteTag()),
+                          this, TQ_SLOT(slotDeleteTag()),
                           actionCollection(), "delete_tag" );
     hint = i18n("Deletes a tag from the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Update to Tag/Date..."), 0,
-                          this, TQT_SLOT(slotUpdateToTag()),
+                          this, TQ_SLOT(slotUpdateToTag()),
                           actionCollection(), "update_to_tag" );
     hint = i18n("Updates the selected files to a given tag, branch or date");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Update to &HEAD"), 0,
-                          this, TQT_SLOT(slotUpdateToHead()),
+                          this, TQ_SLOT(slotUpdateToHead()),
                           actionCollection(), "update_to_head" );
     hint = i18n("Updates the selected files to the HEAD revision");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Merge..."), 0,
-                          this, TQT_SLOT(slotMerge()),
+                          this, TQ_SLOT(slotMerge()),
                           actionCollection(), "merge" );
     hint = i18n("Merges a branch or a set of modifications into the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Add Watch..."), 0,
-                          this, TQT_SLOT(slotAddWatch()),
+                          this, TQ_SLOT(slotAddWatch()),
                           actionCollection(), "add_watch" );
     hint = i18n("Adds a watch for the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Remove Watch..."), 0,
-                          this, TQT_SLOT(slotRemoveWatch()),
+                          this, TQ_SLOT(slotRemoveWatch()),
                           actionCollection(), "remove_watch" );
     hint = i18n("Removes a watch from the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Show &Watchers"), 0,
-                          this, TQT_SLOT(slotShowWatchers()),
+                          this, TQ_SLOT(slotShowWatchers()),
                           actionCollection(), "show_watchers" );
     hint = i18n("Shows the watchers of the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Ed&it Files"), 0,
-                          this, TQT_SLOT(slotEdit()),
+                          this, TQ_SLOT(slotEdit()),
                           actionCollection(), "edit_files" );
     hint = i18n("Edits (cvs edit) the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("U&nedit Files"), 0,
-                          this, TQT_SLOT(slotUnedit()),
+                          this, TQ_SLOT(slotUnedit()),
                           actionCollection(), "unedit_files" );
     hint = i18n("Unedits (cvs unedit) the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Show &Editors"), 0,
-                          this, TQT_SLOT(slotShowEditors()),
+                          this, TQ_SLOT(slotShowEditors()),
                           actionCollection(), "show_editors" );
     hint = i18n("Shows the editors of the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Lock Files"), 0,
-                          this, TQT_SLOT(slotLock()),
+                          this, TQ_SLOT(slotLock()),
                           actionCollection(), "lock_files" );
     hint = i18n("Locks the selected files, so that others cannot modify them");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Unl&ock Files"), 0,
-                          this, TQT_SLOT(slotUnlock()),
+                          this, TQ_SLOT(slotUnlock()),
                           actionCollection(), "unlock_files" );
     hint = i18n("Unlocks the selected files");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Create &Patch Against Repository..."), 0,
-                          this, TQT_SLOT(slotMakePatch()),
+                          this, TQ_SLOT(slotMakePatch()),
                           actionCollection(), "make_patch" );
     hint = i18n("Creates a patch from the modifications in your sandbox");
     action->setToolTip( hint );
@@ -497,25 +497,25 @@ void CervisiaPart::setupActions()
     // Repository Menu
     //
     action = new TDEAction( i18n("&Create..."), 0,
-                          this, TQT_SLOT(slotCreateRepository()),
+                          this, TQ_SLOT(slotCreateRepository()),
                           actionCollection(), "repository_create" );
 
     action = new TDEAction( i18n("&Checkout..."), 0,
-                          this, TQT_SLOT(slotCheckout()),
+                          this, TQ_SLOT(slotCheckout()),
                           actionCollection(), "repository_checkout" );
     hint = i18n("Allows you to checkout a module from a repository");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Import..."), 0,
-                          this, TQT_SLOT(slotImport()),
+                          this, TQ_SLOT(slotImport()),
                           actionCollection(), "repository_import" );
     hint = i18n("Allows you to import a module into a repository");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("&Repositories..."), 0,
-                          this, TQT_SLOT(slotRepositories()),
+                          this, TQ_SLOT(slotRepositories()),
                           actionCollection(), "show_repositories" );
     hint = i18n("Configures a list of repositories you regularly use");
     action->setToolTip( hint );
@@ -525,7 +525,7 @@ void CervisiaPart::setupActions()
     // Settings menu
     //
     TDEToggleAction* toggaction = new TDEToggleAction( i18n("Hide All &Files"), 0,
-                                this, TQT_SLOT(slotHideFiles()),
+                                this, TQ_SLOT(slotHideFiles()),
                                 actionCollection(), "settings_hide_files" );
     toggaction->setCheckedState(i18n("Show All &Files"));
     hint = i18n("Determines whether only folders are shown");
@@ -533,7 +533,7 @@ void CervisiaPart::setupActions()
     toggaction->setWhatsThis( hint );
 
     toggaction = new TDEToggleAction( i18n("Hide Unmodified Files"), 0,
-                                this, TQT_SLOT(slotHideUpToDate()),
+                                this, TQ_SLOT(slotHideUpToDate()),
                                 actionCollection(), "settings_hide_uptodate" );
     toggaction->setCheckedState(i18n("Show Unmodified Files"));
     hint = i18n("Determines whether files with status up-to-date or "
@@ -542,7 +542,7 @@ void CervisiaPart::setupActions()
     toggaction->setWhatsThis( hint );
 
     toggaction = new TDEToggleAction( i18n("Hide Removed Files"), 0,
-                                this, TQT_SLOT(slotHideRemoved()),
+                                this, TQ_SLOT(slotHideRemoved()),
                                 actionCollection(), "settings_hide_removed" );
     toggaction->setCheckedState(i18n("Show Removed Files"));
     hint = i18n("Determines whether removed files are hidden");
@@ -550,7 +550,7 @@ void CervisiaPart::setupActions()
     toggaction->setWhatsThis( hint );
 
     toggaction = new TDEToggleAction( i18n("Hide Non-CVS Files"), 0,
-                                this, TQT_SLOT(slotHideNotInCVS()),
+                                this, TQ_SLOT(slotHideNotInCVS()),
                                 actionCollection(), "settings_hide_notincvs" );
     toggaction->setCheckedState(i18n("Show Non-CVS Files"));
     hint = i18n("Determines whether files not in CVS are hidden");
@@ -558,7 +558,7 @@ void CervisiaPart::setupActions()
     toggaction->setWhatsThis( hint );
 
     toggaction = new TDEToggleAction( i18n("Hide Empty Folders"), 0,
-                                    this, TQT_SLOT(slotHideEmptyDirectories()),
+                                    this, TQ_SLOT(slotHideEmptyDirectories()),
                                     actionCollection(), "settings_hide_empty_directories" );
     toggaction->setCheckedState(i18n("Show Empty Folders"));
     hint = i18n("Determines whether folders without visible entries are hidden");
@@ -566,42 +566,42 @@ void CervisiaPart::setupActions()
     toggaction->setWhatsThis( hint );
 
     action = new TDEToggleAction( i18n("Create &Folders on Update"), 0,
-                                this, TQT_SLOT(slotCreateDirs()),
+                                this, TQ_SLOT(slotCreateDirs()),
                                 actionCollection(), "settings_create_dirs" );
     hint = i18n("Determines whether updates create folders");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEToggleAction( i18n("&Prune Empty Folders on Update"), 0,
-                                this, TQT_SLOT(slotPruneDirs()),
+                                this, TQ_SLOT(slotPruneDirs()),
                                 actionCollection(), "settings_prune_dirs" );
     hint = i18n("Determines whether updates remove empty folders");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEToggleAction( i18n("&Update Recursively"), 0,
-                                this, TQT_SLOT(slotUpdateRecursive()),
+                                this, TQ_SLOT(slotUpdateRecursive()),
                                 actionCollection(), "settings_update_recursively" );
     hint = i18n("Determines whether updates are recursive");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEToggleAction( i18n("C&ommit && Remove Recursively"), 0,
-                                this, TQT_SLOT(slotCommitRecursive()),
+                                this, TQ_SLOT(slotCommitRecursive()),
                                 actionCollection(), "settings_commit_recursively" );
     hint = i18n("Determines whether commits and removes are recursive");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEToggleAction( i18n("Do cvs &edit Automatically When Necessary"), 0,
-                                this, TQT_SLOT(slotDoCVSEdit()),
+                                this, TQ_SLOT(slotDoCVSEdit()),
                                 actionCollection(), "settings_do_cvs_edit" );
     hint = i18n("Determines whether automatic cvs editing is active");
     action->setToolTip( hint );
     action->setWhatsThis( hint );
 
     action = new TDEAction( i18n("Configure Cervisia..."), "configure", 0,
-                          this, TQT_SLOT(slotConfigure()),
+                          this, TQ_SLOT(slotConfigure()),
                           actionCollection(), "configure_cervisia" );
     hint = i18n("Allows you to configure the Cervisia KPart");
     action->setToolTip( hint );
@@ -610,11 +610,11 @@ void CervisiaPart::setupActions()
     //
     // Help Menu
     //
-    action = KStdAction::help( this, TQT_SLOT(slotHelp()),
+    action = KStdAction::help( this, TQ_SLOT(slotHelp()),
                                actionCollection() );
 
     action = new TDEAction( i18n("CVS &Manual"), 0,
-                          this, TQT_SLOT(slotCVSInfo()),
+                          this, TQ_SLOT(slotCVSInfo()),
                           actionCollection(), "help_cvs_manual" );
     hint = i18n("Opens the help browser with the CVS documentation");
     action->setToolTip( hint );
@@ -624,11 +624,11 @@ void CervisiaPart::setupActions()
     // Folder context menu
     //
     toggaction = new TDEToggleAction( i18n("Unfold Folder"), 0,
-                                    this, TQT_SLOT( slotUnfoldFolder() ),
+                                    this, TQ_SLOT( slotUnfoldFolder() ),
                                     actionCollection(), "unfold_folder" );
     toggaction->setCheckedState(i18n("Fold Folder"));
 
-    //action = KStdAction::aboutApp( this, TQT_SLOT(aboutCervisia()),
+    //action = KStdAction::aboutApp( this, TQ_SLOT(aboutCervisia()),
     //               actionCollection(), "help_about_cervisia" );
 }
 
@@ -881,9 +881,9 @@ void CervisiaPart::slotStatus()
     if( protocol->startJob(true) )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(receivedLine(TQString)), update, TQT_SLOT(processUpdateLine(TQString)) );
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)), update, TQT_SLOT(finishJob(bool, int)) );
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)), this, TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(receivedLine(TQString)), update, TQ_SLOT(processUpdateLine(TQString)) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)), update, TQ_SLOT(finishJob(bool, int)) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)), this, TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -992,8 +992,8 @@ void CervisiaPart::slotCommit()
         {
             m_jobType = Commit;
             showJobStart(cmdline);
-            connect( protocol, TQT_SIGNAL(jobFinished(bool, int)), update, TQT_SLOT(finishJob(bool, int)) );
-            connect( protocol, TQT_SIGNAL(jobFinished(bool, int)), this, TQT_SLOT(slotJobFinished()) );
+            connect( protocol, TQ_SIGNAL(jobFinished(bool, int)), update, TQ_SLOT(finishJob(bool, int)) );
+            connect( protocol, TQ_SIGNAL(jobFinished(bool, int)), this, TQ_SLOT(slotJobFinished()) );
         }
     }
 }
@@ -1060,9 +1060,9 @@ void CervisiaPart::updateSandbox(const TQString &extraopt)
     if( protocol->startJob(true) )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(receivedLine(TQString)), update, TQT_SLOT(processUpdateLine(TQString)) );
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)), update, TQT_SLOT(finishJob(bool, int)) );
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)), this, TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(receivedLine(TQString)), update, TQ_SLOT(processUpdateLine(TQString)) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)), update, TQ_SLOT(finishJob(bool, int)) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)), this, TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -1108,10 +1108,10 @@ void CervisiaPart::addOrRemove(AddRemoveDialog::ActionType action)
         if (protocol->startJob())
         {
             showJobStart(cmdline);
-            connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                     update, TQT_SLOT(finishJob(bool, int)) );
-            connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                     this, TQT_SLOT(slotJobFinished()) );
+            connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                     update, TQ_SLOT(finishJob(bool, int)) );
+            connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                     this, TQ_SLOT(slotJobFinished()) );
         }
     }
 }
@@ -1211,8 +1211,8 @@ void CervisiaPart::addOrRemoveWatch(WatchDialog::ActionType action)
         if( protocol->startJob() )
         {
             showJobStart(cmdline);
-            connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                     this,     TQT_SLOT(slotJobFinished()) );
+            connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                     this,     TQ_SLOT(slotJobFinished()) );
         }
     }
 }
@@ -1247,8 +1247,8 @@ void CervisiaPart::slotEdit()
     if( protocol->startJob() )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                 this,     TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                 this,     TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -1267,8 +1267,8 @@ void CervisiaPart::slotUnedit()
     if( protocol->startJob() )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                 this,     TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                 this,     TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -1287,8 +1287,8 @@ void CervisiaPart::slotLock()
     if( protocol->startJob() )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                 this,     TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                 this,     TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -1307,8 +1307,8 @@ void CervisiaPart::slotUnlock()
     if( protocol->startJob() )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                 this,     TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                 this,     TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -1327,8 +1327,8 @@ void CervisiaPart::slotShowEditors()
     if( protocol->startJob() )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                 this,     TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                 this,     TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -1394,8 +1394,8 @@ void CervisiaPart::slotImport()
     if( protocol->startJob() )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                 this,     TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                 this,     TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -1414,8 +1414,8 @@ void CervisiaPart::slotCreateRepository()
     if( protocol->startJob() )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                 this,     TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                 this,     TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -1437,8 +1437,8 @@ void CervisiaPart::slotCheckout()
     if( protocol->startJob() )
     {
         showJobStart(cmdline);
-        connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                 this,     TQT_SLOT(slotJobFinished()) );
+        connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                 this,     TQ_SLOT(slotJobFinished()) );
     }
 }
 
@@ -1487,8 +1487,8 @@ void CervisiaPart::createOrDeleteTag(TagDialog::ActionType action)
         if( protocol->startJob() )
         {
             showJobStart(cmdline);
-            connect( protocol, TQT_SIGNAL(jobFinished(bool, int)),
-                     this,     TQT_SLOT(slotJobFinished()) );
+            connect( protocol, TQ_SIGNAL(jobFinished(bool, int)),
+                     this,     TQ_SLOT(slotJobFinished()) );
         }
     }
 }
@@ -1635,8 +1635,8 @@ void CervisiaPart::slotConfigure()
     conf->setGroup("LookAndFeel");
     bool splitHorz = conf->readBoolEntry("SplitHorizontally",true);
     splitter->setOrientation( splitHorz ?
-                              Qt::Vertical :
-                              Qt::Horizontal);
+                              TQt::Vertical :
+                              TQt::Horizontal);
 }
 
 void CervisiaPart::slotHelp()
@@ -1687,8 +1687,8 @@ void CervisiaPart::slotJobFinished()
     emit setStatusBarText( i18n("Done") );
     updateActions();
 
-    disconnect( protocol, TQT_SIGNAL(receivedLine(TQString)),
-                update,   TQT_SLOT(processUpdateLine(TQString)) );
+    disconnect( protocol, TQ_SIGNAL(receivedLine(TQString)),
+                update,   TQ_SLOT(processUpdateLine(TQString)) );
 
     if( m_jobType == Commit )
     {
