@@ -27,7 +27,7 @@ class TDEConfig;
 
 class FilesSettings : public SettingsBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	FilesSettings( TQWidget* parent );
