@@ -38,7 +38,7 @@ class UMLView;
 
 class SelectOpDlg : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
